#
#  Copyright 1996-2011 Jim Pirzyk / pirzyk.org
#  All rights reserved.
#
#  Security::exports - NFS server checks
#
package Security::exports;

use Exporter;
use strict;
use warnings;

our @ISA = qw(Exporter);
our @EXPORT_OK = qw( &init() &check() &print() );

our (%exports);

sub init {
	print ( STDERR  "In Security::exports::init()\n") if ( $main::opts{'d'} );

	printf STDERR "Need to define \$showmount in Security::$^O.pm\n"
		if ( ! defined $main::showmount );
}

# Check to see what hosts have filesystems exported R/W to the world.  This 
# idea comes from the HP-UX System Security manual
sub check {
	local *FP;
	my ($dir, $dummy, @matches, @lines, $rofound);

	print ( STDERR "In Security::exports::check()\n") if ( $main::opts{'d'} );
	if ( -f $main::showmount ) {
		open(FP, "$main::showmount -e localhost 2>/dev/null |") || &main::security_die ("Could not run $main::showmount\n");
		while (<FP>) {
			chop;
			$dummy = $_;
			$dummy =~ s/^.* //o;
			$dir = $_;
			$dir =~ s/ .*$//o;

			# Now double check to see if the filesystem is RO or RW
			if ($dummy =~ /\(everyone\)/o) {

				# If we have not read in the exports file, do so.
				if ( -f $main::exportsfile && ! scalar @lines) {
					open(FP2, "$main::exportsfile") || &main::security_die ("Could not open exports file $main::exportsfile\n");
					@lines = <FP2>;
					close FP2;
				}

				if ( scalar @lines ) {
					$rofound = 0;
					@matches = grep (/$dir\b/, @lines);
					grep (/\bro\b/ && ($rofound=1), @matches);
					$exports{$dir} = 1 if ( ! $rofound );
				} else {
					$exports{$dir} = 1;
				}
			}
		}
		close FP;
	}
}

sub print {
	print ( STDERR  "In Security::exports::print()\n") if ( $main::opts{'d'} );

	&main::print_data ("\n\nchecking for world exported filesystems:\n", %exports);
}

1;

__END__

=head1 NAME

Security::exports - Find world exported RW filesystems.

=head1 SYNOPSIS

Security::exports::init()

Security::exports::check()

Security::exports::print()

=head1 DESCRIPTION

Check for RW filesystems that are exported to the world.

=head1 API

This module implements the default API:

=over 4

=item C<init()>

Will check to see if C<$main::showmount> is defined.

=item C<check()>

Runs the C<$main::showmount> command to get the list of filesystems
exported.  If the filesystem is exported to the world, then read through
the C<$main::exportsfile> to see if it is exported RW.

=item C<print()>

Calls C<print_data ()> to print out the list of RW exported filesystems
that we found.

=back 

=head1 HISTORY

This idea of tracking world exported filesystems was suggeted in the
C<HP-UX System Security Manual>.

It was suggeted by a UIUC co-worker that this only is a concern if the
filesystem is exported RW.

=head1 SEE ALSO

L<showmount(8)>

L<exports(5)>

L<dfstab(5)>

L<nfs>

=cut

