#
#  Copyright 1996-2011 Jim Pirzyk / pirzyk.org
#  All rights reserved.
#
#  Security::util::uniq - Return only the unique elements in an array
#
package Security::util::uniq;

use Exporter;
use strict;
use warnings;

our @ISA = qw(Exporter);
our @EXPORT_OK = qw( &uniq());

sub uniq {
	my (@a) = @_;
	my (%b);

	map { $b{$_} = 1 } @a;

	return keys %b;
}

1;

__END__

=head1 NAME

Security::util::uniq - Return only the unique elements in an array

=head1 SYNOPSIS

@uniq = &uniq(@array);

=head1 DESCRIPTION

Module to return only the unique values in an array.

=head1 API

It provides the following API calls for other modules to use.

=over 4

=item C<uniq(@array)>

Uses perl hash keys to return only the unique elements in the array,
order is B<not> guaranteed.

=back

=head1 SEE ALSO

L<sort>

=cut
